Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(899)

Unified Diff: src/transitions.h

Issue 801813002: Using PropertyKind in transitions instead of PropertyType. (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: Created 6 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/objects-inl.h ('k') | src/transitions.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/transitions.h
diff --git a/src/transitions.h b/src/transitions.h
index 5f211497eb6ee6fab58fbb5a57d1aeb9e0a71e42..999ad86c558c176f8bb112df840b626f81c36cbb 100644
--- a/src/transitions.h
+++ b/src/transitions.h
@@ -98,8 +98,8 @@ class TransitionArray: public FixedArray {
static Handle<TransitionArray> Insert(Handle<Map> map, Handle<Name> name,
Handle<Map> target,
SimpleTransitionFlag flag);
- // Search a transition for a given type, property name and attributes.
- int Search(PropertyType type, Name* name, PropertyAttributes attributes,
+ // Search a transition for a given kind, property name and attributes.
+ int Search(PropertyKind kind, Name* name, PropertyAttributes attributes,
int* out_insertion_index = NULL);
// Search a non-property transition (like elements kind, observe or frozen
@@ -216,15 +216,14 @@ class TransitionArray: public FixedArray {
// Search a first transition for a given property name.
inline int SearchName(Name* name, int* out_insertion_index = NULL);
- int SearchDetails(int transition, PropertyType type,
+ int SearchDetails(int transition, PropertyKind kind,
PropertyAttributes attributes, int* out_insertion_index);
// Compares two tuples <key, is_data_property, attributes>, returns -1 if
// tuple1 is "less" than tuple2, 0 if tuple1 equal to tuple2 and 1 otherwise.
- static inline int CompareKeys(Name* key1, uint32_t hash1,
- bool is_data_property1,
+ static inline int CompareKeys(Name* key1, uint32_t hash1, PropertyKind kind1,
PropertyAttributes attributes1, Name* key2,
- uint32_t hash2, bool is_data_property2,
+ uint32_t hash2, PropertyKind kind2,
PropertyAttributes attributes2);
// Compares keys, returns -1 if key1 is "less" than key2,
@@ -234,9 +233,9 @@ class TransitionArray: public FixedArray {
// Compares two details, returns -1 if details1 is "less" than details2,
// 0 if details1 equal to details2 and 1 otherwise.
- static inline int CompareDetails(bool is_data_property1,
+ static inline int CompareDetails(PropertyKind kind1,
PropertyAttributes attributes1,
- bool is_data_property2,
+ PropertyKind kind2,
PropertyAttributes attributes2);
inline void NoIncrementalWriteBarrierSet(int transition_number,
« no previous file with comments | « src/objects-inl.h ('k') | src/transitions.cc » ('j') | no next file with comments »
@@ -216,15 +216,14 @@ class TransitionArray: public FixedArray {
PropertyAttributes attributes, int* out_insertion_index);
- // Compares two tuples <key, is_data_property, attributes>, returns -1 if
+ // Compares two tuples <key, kind, attributes>, returns -1 if
// tuple1 is "less" than tuple2, 0 if tuple1 equal to tuple2 and 1 otherwise.

Powered by Google App Engine
This is Rietveld 408576698